[−][src]Struct soa_vec::Soa2
Stores slices in a struct-of-arrays style with the API of Vec. The advantage over simply using multiple Vec is that all slices live in a single allocation, there's one shared len/capacity variable, and the API ensures that items are kept together through all operations like push/pop/sort
Methods
impl<T1: Sized, T2: Sized> Soa2<T1, T2>[src]
pub fn new() -> Soa2<T1, T2>[src]
pub fn len(&self) -> usize[src]
pub fn clear(&mut self)[src]
pub fn push(&mut self, value: (T1, T2))[src]
pub fn pop(&mut self) -> Option<(T1, T2)>[src]
pub fn swap_remove(&mut self, index: usize) -> (T1, T2)[src]
##Panics:
- Must panic if index is out of bounds
pub fn slices<'a>(&self) -> (&'a [T1], &'a [T2])[src]
pub fn iters<'a>(&self) -> (Iter<'a, T1>, Iter<'a, T2>)[src]
pub fn slices_mut<'a>(&self) -> (&'a mut [T1], &'a mut [T2])[src]
pub fn get<'a>(&self, index: usize) -> (&'a T1, &'a T2)[src]
Panics
- If index is >= len
pub fn sort_unstable_by<F: FnMut((&T1, &T2), (&T1, &T2)) -> Ordering>(
&mut self,
f: F
)[src]
&mut self,
f: F
)